FlexWidget class

Inheritance

Constructors

FlexWidget({Widget? child, FlexBuilder? builder, int xs = 12, int xsOffset = 0, int? xsLand, int? xsLandOffset, int sm = 6, int smOffset = 0, int? smLand, int? smLandOffset, int md = 6, int mdOffset = 0, int? mdLand, int? mdLandOffset, int lg = 3, int lgOffset = 0, int? lgLand, int? lgLandOffset, int xl = 3, int xlOffset = 0, int xlLand = 0, int? xlLandOffset, int xxl = 3, int xxlOffset = 0, int? xxlLand, int? xxlLandOffset, int xxxl = 3, int xxxlOffset = 0, int? xxxlLand, int? xxxlLandOffset})

Properties

builder → FlexBuilder
builder according column calc
finalinherited
columns ↔ Map<int, int?>
Columns counts for each grid type
getter/setter pairinherited
columnsLand ↔ Map<int, int?>
Columns counts for each grid type and the device is landscape
getter/setter pairinherited
gridName ↔ Map<int, String>
Map to translate gridsize id to a name
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offsets ↔ Map<int, int>
Columns offset for each grid type
getter/setter pairinherited
offsetsLand ↔ Map<int, int>
Columns offset for each grid type and the device is landscape
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
calcOffset(Size size, Orientation orientation, int columnsCount) → double
Calc the offset in pixels, for the screen and rotation config used actually in the device
inherited
calcWidth(Size size, Orientation orientation, int columnsCount) → double
Calc the width in pixels, for the screen and rotation config used actually in the device
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited