FlexColumns class

Constructors

FlexColumns({required int xs, int? sm, int? md, int? lg, int? xl, int? xxl, int? xxxl})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ Map<int, int?>
Columns counts for each grid type and the device is landscape
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited