Responsive mixin

Mixin applications

Properties

columns ↔ Map<int, int?>
Columns counts for each grid type
getter/setter pair
columnsLand ↔ Map<int, int?>
Columns counts for each grid type and the device is landscape
getter/setter pair
gridName ↔ Map<int, String>
Map to translate gridsize id to a name
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offsets ↔ Map<int, int>
Columns offset for each grid type
getter/setter pair
offsetsLand ↔ Map<int, int>
Columns offset for each grid type and the device is landscape
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calcOffset(Size size, Orientation orientation, int columnsCount) → double
Calc the offset in pixels, for the screen and rotation config used actually in the device
calcWidth(Size size, Orientation orientation, int columnsCount) → double
Calc the width in pixels, for the screen and rotation config used actually in the device
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

calcColumns({Size? size, Orientation? orientation, required FlexColumns columns, BuildContext? context}) → int?
Calc the number of columns, for the screen and rotation config used actually in the device
gridSize(double width) → int
Method to return grid size name

Constants

lg → const int
md → const int
sm → const int
xl → const int
xs → const int
xxl → const int
xxxl → const int